/* namespace.c generated by valac, the Vala compiler
 * generated from namespace.vala, do not modify */

/* namespace.vala
 *
 * Copyright (C) 2008-2011  Florian Brosch
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301  USA
 *
 * Author:
 * 	Florian Brosch <flo.brosch@gmail.com>
 */

#include "valadoc.h"
#include <glib.h>
#include <glib-object.h>
#include <stdlib.h>
#include <string.h>
#include <vala.h>

#if !defined(VALA_STRICT_C)
#if !defined(__clang__) && defined(__GNUC__) && (__GNUC__ >= 14)
#pragma GCC diagnostic warning "-Wincompatible-pointer-types"
#elif defined(__clang__) && (__clang_major__ >= 16)
#pragma clang diagnostic ignored "-Wincompatible-function-pointer-types"
#pragma clang diagnostic ignored "-Wincompatible-pointer-types"
#endif
#endif

enum  {
	VALADOC_API_NAMESPACE_0_PROPERTY,
	VALADOC_API_NAMESPACE_NODE_TYPE_PROPERTY,
	VALADOC_API_NAMESPACE_NUM_PROPERTIES
};
static GParamSpec* valadoc_api_namespace_properties[VALADOC_API_NAMESPACE_NUM_PROPERTIES];
#define _valadoc_api_signature_builder_unref0(var) ((var == NULL) ? NULL : (var = (valadoc_api_signature_builder_unref (var), NULL)))

static gpointer valadoc_api_namespace_parent_class = NULL;

static ValadocContentInline* valadoc_api_namespace_real_build_signature (ValadocApiItem* base);
static void valadoc_api_namespace_real_accept (ValadocApiNode* base,
                                        ValadocApiVisitor* visitor);
static gboolean valadoc_api_namespace_real_is_browsable (ValadocApiNode* base,
                                                  ValadocSettings* settings);
static GType valadoc_api_namespace_get_type_once (void);
static void _vala_valadoc_api_namespace_get_property (GObject * object,
                                               guint property_id,
                                               GValue * value,
                                               GParamSpec * pspec);

ValadocApiNamespace*
valadoc_api_namespace_construct (GType object_type,
                                 ValadocApiNode* parent,
                                 ValadocApiSourceFile* file,
                                 const gchar* name,
                                 ValadocApiSourceComment* comment,
                                 ValaNamespace* data)
{
	ValadocApiNamespace * self = NULL;
	g_return_val_if_fail (parent != NULL, NULL);
	g_return_val_if_fail (file != NULL, NULL);
	g_return_val_if_fail (data != NULL, NULL);
	self = (ValadocApiNamespace*) valadoc_api_symbol_construct (object_type, parent, file, name, VALA_SYMBOL_ACCESSIBILITY_PUBLIC, comment, (ValaSymbol*) data);
	return self;
}

ValadocApiNamespace*
valadoc_api_namespace_new (ValadocApiNode* parent,
                           ValadocApiSourceFile* file,
                           const gchar* name,
                           ValadocApiSourceComment* comment,
                           ValaNamespace* data)
{
	return valadoc_api_namespace_construct (VALADOC_API_TYPE_NAMESPACE, parent, file, name, comment, data);
}

/**
 * {@inheritDoc}
 */
static ValadocContentInline*
valadoc_api_namespace_real_build_signature (ValadocApiItem* base)
{
	ValadocApiNamespace * self;
	ValadocApiSignatureBuilder* _tmp0_;
	ValadocApiSignatureBuilder* _tmp1_;
	ValaSymbolAccessibility _tmp2_;
	ValaSymbolAccessibility _tmp3_;
	const gchar* _tmp4_;
	ValadocApiSignatureBuilder* _tmp5_;
	ValadocApiSignatureBuilder* _tmp6_;
	ValadocApiSignatureBuilder* _tmp7_;
	ValadocContentRun* _tmp8_;
	ValadocContentInline* _tmp9_;
	ValadocContentInline* result;
	self = (ValadocApiNamespace*) base;
	_tmp0_ = valadoc_api_signature_builder_new ();
	_tmp1_ = _tmp0_;
	_tmp2_ = valadoc_api_symbol_get_accessibility ((ValadocApiSymbol*) self);
	_tmp3_ = _tmp2_;
	_tmp4_ = vala_symbol_accessibility_to_string (_tmp3_);
	_tmp5_ = valadoc_api_signature_builder_append_keyword (_tmp1_, _tmp4_, TRUE);
	_tmp6_ = valadoc_api_signature_builder_append_keyword (_tmp5_, "namespace", TRUE);
	_tmp7_ = valadoc_api_signature_builder_append_symbol (_tmp6_, (ValadocApiNode*) self, TRUE);
	_tmp8_ = valadoc_api_signature_builder_get (_tmp7_);
	_tmp9_ = (ValadocContentInline*) _tmp8_;
	_valadoc_api_signature_builder_unref0 (_tmp1_);
	result = _tmp9_;
	return result;
}

static ValadocApiNodeType
valadoc_api_namespace_real_get_node_type (ValadocApiNode* base)
{
	ValadocApiNodeType result;
	ValadocApiNamespace* self;
	self = (ValadocApiNamespace*) base;
	result = VALADOC_API_NODE_TYPE_NAMESPACE;
	return result;
}

/**
 * {@inheritDoc}
 */
static void
valadoc_api_namespace_real_accept (ValadocApiNode* base,
                                   ValadocApiVisitor* visitor)
{
	ValadocApiNamespace * self;
	self = (ValadocApiNamespace*) base;
	g_return_if_fail (visitor != NULL);
	valadoc_api_visitor_visit_namespace (visitor, self);
}

/**
 * {@inheritDoc}
 */
static gboolean
valadoc_api_namespace_real_is_browsable (ValadocApiNode* base,
                                         ValadocSettings* settings)
{
	ValadocApiNamespace * self;
	gboolean result;
	self = (ValadocApiNamespace*) base;
	g_return_val_if_fail (settings != NULL, FALSE);
	result = valadoc_api_node_has_visible_children ((ValadocApiNode*) self, settings);
	return result;
}

static void
valadoc_api_namespace_class_init (ValadocApiNamespaceClass * klass,
                                  gpointer klass_data)
{
	valadoc_api_namespace_parent_class = g_type_class_peek_parent (klass);
	((ValadocApiItemClass *) klass)->build_signature = (ValadocContentInline* (*) (ValadocApiItem*)) valadoc_api_namespace_real_build_signature;
	((ValadocApiNodeClass *) klass)->accept = (void (*) (ValadocApiNode*, ValadocApiVisitor*)) valadoc_api_namespace_real_accept;
	((ValadocApiNodeClass *) klass)->is_browsable = (gboolean (*) (ValadocApiNode*, ValadocSettings*)) valadoc_api_namespace_real_is_browsable;
	VALADOC_API_NODE_CLASS (klass)->get_node_type = (ValadocApiNodeType (*) (ValadocApiNode*)) valadoc_api_namespace_real_get_node_type;
	G_OBJECT_CLASS (klass)->get_property = _vala_valadoc_api_namespace_get_property;
	/**
	 * {@inheritDoc}
	 */
	g_object_class_install_property (G_OBJECT_CLASS (klass), VALADOC_API_NAMESPACE_NODE_TYPE_PROPERTY, valadoc_api_namespace_properties[VALADOC_API_NAMESPACE_NODE_TYPE_PROPERTY] = g_param_spec_enum ("node-type", "node-type", "node-type", VALADOC_API_TYPE_NODE_TYPE, 0, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE));
}

static void
valadoc_api_namespace_instance_init (ValadocApiNamespace * self,
                                     gpointer klass)
{
}

/**
 * Represents a namespace declaration.
 */
static GType
valadoc_api_namespace_get_type_once (void)
{
	static const GTypeInfo g_define_type_info = { sizeof (ValadocApiNamespaceClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) valadoc_api_namespace_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValadocApiNamespace), 0, (GInstanceInitFunc) valadoc_api_namespace_instance_init, NULL };
	GType valadoc_api_namespace_type_id;
	valadoc_api_namespace_type_id = g_type_register_static (VALADOC_API_TYPE_SYMBOL, "ValadocApiNamespace", &g_define_type_info, 0);
	return valadoc_api_namespace_type_id;
}

GType
valadoc_api_namespace_get_type (void)
{
	static volatile gsize valadoc_api_namespace_type_id__once = 0;
	if (g_once_init_enter (&valadoc_api_namespace_type_id__once)) {
		GType valadoc_api_namespace_type_id;
		valadoc_api_namespace_type_id = valadoc_api_namespace_get_type_once ();
		g_once_init_leave (&valadoc_api_namespace_type_id__once, valadoc_api_namespace_type_id);
	}
	return valadoc_api_namespace_type_id__once;
}

static void
_vala_valadoc_api_namespace_get_property (GObject * object,
                                          guint property_id,
                                          GValue * value,
                                          GParamSpec * pspec)
{
	ValadocApiNamespace * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, VALADOC_API_TYPE_NAMESPACE, ValadocApiNamespace);
	switch (property_id) {
		case VALADOC_API_NAMESPACE_NODE_TYPE_PROPERTY:
		g_value_set_enum (value, valadoc_api_node_get_node_type ((ValadocApiNode*) self));
		break;
		default:
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
		break;
	}
}

